@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,71 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     Atome = 258,
-     SpcPlus = 259,
-     Plus = 260,
-     Moins = 261,
-     Mul = 262,
-     Fleche = 263,
-     Int = 264,
-     Charge = 265,
-     Frac = 266,
-     Real = 267,
-     SpcLpar = 268,
-     Lpar = 269,
-     Rpar = 270,
-     Lsq = 271,
-     Rsq = 272,
-     Haut = 273,
-     Spc = 274,
-     Sol = 275,
-     Gas = 276,
-     Aqueous = 277,
-     Egal = 278,
-     Compose = 279,
-     AntiCompose = 280
-   };
-#endif
-/* Tokens.  */
-#define Atome 258
-#define SpcPlus 259
-#define Plus 260
-#define Moins 261
-#define Mul 262
-#define Fleche 263
-#define Int 264
-#define Charge 265
-#define Frac 266
-#define Real 267
-#define SpcLpar 268
-#define Lpar 269
-#define Rpar 270
-#define Lsq 271
-#define Rsq 272
-#define Haut 273
-#define Spc 274
-#define Sol 275
-#define Gas 276
-#define Aqueous 277
-#define Egal 278
-#define Compose 279
-#define AntiCompose 280
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 2 "chemeq.y"
 
 /* inclusions, définition */
@@ -158,6 +106,9 @@ typedef struct{
 
 
 
+/* Line 189 of yacc.c  */
+#line 111 "chemparser.cc"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -176,20 +127,54 @@ typedef struct{
 # define YYTOKEN_TABLE 0
 #endif
 
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef int YYSTYPE;
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     Atome = 258,
+     SpcPlus = 259,
+     Plus = 260,
+     Moins = 261,
+     Mul = 262,
+     Fleche = 263,
+     Int = 264,
+     Charge = 265,
+     Frac = 266,
+     Real = 267,
+     SpcLpar = 268,
+     Lpar = 269,
+     Rpar = 270,
+     Lsq = 271,
+     Rsq = 272,
+     Haut = 273,
+     Spc = 274,
+     Sol = 275,
+     Gas = 276,
+     Aqueous = 277,
+     Egal = 278,
+     Compose = 279,
+     AntiCompose = 280
+   };
 #endif
 
 
 
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef int YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+#endif
+
+
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 193 "chemparser.cc"
+/* Line 264 of yacc.c  */
+#line 178 "chemparser.cc"
 
 #ifdef short
 # undef short
@@ -264,14 +249,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -352,9 +337,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -388,12 +373,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -833,17 +818,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -877,11 +865,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1161,10 +1149,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1180,11 +1166,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1192,9 +1177,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1218,14 +1203,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1233,51 +1243,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1307,7 +1294,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1315,7 +1301,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1338,9 +1323,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1351,7 +1335,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1361,6 +1344,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1369,16 +1355,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1410,20 +1396,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1463,6 +1445,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 66 "chemeq.y"
     { 
   result=(yyvsp[(1) - (1)]);
@@ -1471,6 +1455,8 @@ yyreduce:
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 70 "chemeq.y"
     {
   result=(yyvsp[(1) - (1)]);
@@ -1479,11 +1465,15 @@ yyreduce:
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 76 "chemeq.y"
-    {(yyval)=(yyvsp[(1) - (1)]);}
+    {(yyval)=(yyvsp[(1) - (1)]);;}
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 77 "chemeq.y"
     {
   (yyvsp[(1) - (5)]).cq->addChemeq((yyvsp[(5) - (5)]).cq);
@@ -1492,6 +1482,8 @@ yyreduce:
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 81 "chemeq.y"
     { 
   (yyvsp[(1) - (5)]).cq->subChemeq((yyvsp[(5) - (5)]).cq);
@@ -1500,6 +1492,8 @@ yyreduce:
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 87 "chemeq.y"
     {
   (yyval)=(yyvsp[(1) - (2)]);
@@ -1509,6 +1503,8 @@ yyreduce:
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 92 "chemeq.y"
     {
   (yyval).cq = (yyvsp[(5) - (5)]).cq; (yyval).cq->multiply((yyvsp[(1) - (5)]).i,(yyvsp[(1) - (5)]).d);
@@ -1516,6 +1512,8 @@ yyreduce:
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 95 "chemeq.y"
     {
   (yyval).cq = (yyvsp[(5) - (5)]).cq; (yyval).cq->multiply((yyvsp[(1) - (5)]).i,1);
@@ -1523,66 +1521,92 @@ yyreduce:
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 100 "chemeq.y"
     {(yyval).s = ""; (yyval).r = MINVAL; /* valeur négative : non défini */;}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 101 "chemeq.y"
     {(yyval) = (yyvsp[(2) - (3)]);;}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 104 "chemeq.y"
     {(yyval).s = ""; (yyval).r = (yyvsp[(2) - (3)]).r;;}
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 105 "chemeq.y"
     {(yyval).s = (yyvsp[(2) - (7)]).s; (yyval).r = (yyvsp[(6) - (7)]).r;;}
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 108 "chemeq.y"
     {(yyval).r=(yyvsp[(1) - (1)]).r;;}
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 109 "chemeq.y"
     {(yyval).r=1.0*(yyvsp[(1) - (1)]).i;;}
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 110 "chemeq.y"
     {(yyval).r=(yyvsp[(3) - (3)]).r;;}
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 111 "chemeq.y"
     {(yyval).r=-(yyvsp[(3) - (3)]).r;;}
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 112 "chemeq.y"
     {(yyval).r=1.0*(yyvsp[(3) - (3)]).i;;}
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 113 "chemeq.y"
     {(yyval).r=-1.0*(yyvsp[(3) - (3)]).i;;}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 117 "chemeq.y"
     {if ((yyvsp[(2) - (2)]).s.compare("V")!=0) yyerror ("only 'V' allowed as unit"); ;}
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 120 "chemeq.y"
     {/* $$.s contient le nom */;}
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 123 "chemeq.y"
     {
   (yyval).cq = new Chemeq((yyvsp[(1) - (5)]).mb,(yyvsp[(5) - (5)]).mb);
@@ -1590,6 +1614,8 @@ yyreduce:
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 128 "chemeq.y"
     {
   (yyval).mb->addMol((yyvsp[(4) - (4)]).m);
@@ -1597,6 +1623,8 @@ yyreduce:
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 131 "chemeq.y"
     {
   (yyval).mb = new Membre;
@@ -1605,6 +1633,8 @@ yyreduce:
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 137 "chemeq.y"
     {
   (yyval) = (yyvsp[(3) - (3)]);
@@ -1613,6 +1643,8 @@ yyreduce:
     break;
 
   case 27:
+
+/* Line 1455 of yacc.c  */
 #line 141 "chemeq.y"
     {
   (yyval) = (yyvsp[(3) - (3)]);
@@ -1621,6 +1653,8 @@ yyreduce:
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 145 "chemeq.y"
     {
   (yyval) = (yyvsp[(1) - (1)]); 
@@ -1628,6 +1662,8 @@ yyreduce:
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 154 "chemeq.y"
     {
   (yyval).m = new Molec((yyvsp[(1) - (2)]).al,0); (yyval).m->typage((yyvsp[(2) - (2)]).t);
@@ -1635,6 +1671,8 @@ yyreduce:
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 157 "chemeq.y"
     {
   (yyval).m = new Molec((yyvsp[(1) - (3)]).al,(yyvsp[(2) - (3)]).i);(yyval).m->typage((yyvsp[(3) - (3)]).t);
@@ -1642,61 +1680,85 @@ yyreduce:
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 163 "chemeq.y"
     {(yyval).al=(yyvsp[(1) - (1)]).al;;}
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 164 "chemeq.y"
     {(yyval).al=(yyvsp[(3) - (5)]).al; (yyval).al->sq(1);;}
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 167 "chemeq.y"
     {(yyval).t = aqueous;;}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 168 "chemeq.y"
     {(yyval).t = aqueous;;}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 169 "chemeq.y"
     {(yyval).t = sol;;}
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 170 "chemeq.y"
     {(yyval).t = gas;;}
     break;
 
   case 39:
+
+/* Line 1455 of yacc.c  */
 #line 173 "chemeq.y"
     {(yyval).i=1;;}
     break;
 
   case 40:
+
+/* Line 1455 of yacc.c  */
 #line 174 "chemeq.y"
     {(yyval).i=1;;}
     break;
 
   case 41:
+
+/* Line 1455 of yacc.c  */
 #line 175 "chemeq.y"
     {(yyval).i=(yyvsp[(2) - (2)]).i;;}
     break;
 
   case 42:
+
+/* Line 1455 of yacc.c  */
 #line 176 "chemeq.y"
     {(yyval).i=-1;;}
     break;
 
   case 43:
+
+/* Line 1455 of yacc.c  */
 #line 177 "chemeq.y"
     {(yyval).i=-1;;}
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 180 "chemeq.y"
     {
   (yyval)=(yyvsp[(2) - (3)]); 
@@ -1704,6 +1766,8 @@ yyreduce:
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 185 "chemeq.y"
     {
   (yyval).al = new AtomeListe("",0,0,(yyvsp[(1) - (1)]).al);
@@ -1711,6 +1775,8 @@ yyreduce:
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 188 "chemeq.y"
     {
   char buffer[25];
@@ -1723,6 +1789,8 @@ yyreduce:
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 198 "chemeq.y"
     {
   (yyval) = (yyvsp[(1) - (3)]);
@@ -1732,6 +1800,8 @@ yyreduce:
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 203 "chemeq.y"
     {
   (yyval).al = (yyvsp[(1) - (2)]).al;
@@ -1740,6 +1810,8 @@ yyreduce:
     break;
 
   case 49:
+
+/* Line 1455 of yacc.c  */
 #line 209 "chemeq.y"
     {
   (yyval).i=1;
@@ -1747,6 +1819,8 @@ yyreduce:
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 212 "chemeq.y"
     {
   (yyval)=(yyvsp[(1) - (1)]); 
@@ -1754,8 +1828,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1759 "chemparser.cc"
+
+/* Line 1455 of yacc.c  */
+#line 1834 "chemparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1766,7 +1841,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1831,7 +1905,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1848,7 +1922,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1905,9 +1979,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1932,7 +2003,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1943,7 +2014,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1969,6 +2040,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 217 "chemeq.y"
 
 #include "chemlex.cc"
